<TeXmacs|1.0.7.8>

<style|source>

<\body>
  <\active*>
    <\src-title>
      <src-style-file|beamer|1.0>

      <\src-purpose>
        The beamer style for presentations from a laptop.
      </src-purpose>

      <\src-copyright|2010>
        Joris van der Hoeven
      </src-copyright>

      <\src-license>
        This software falls under the <hlink|GNU general public license,
        version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
        WARRANTY WHATSOEVER. You should have received a copy of the license
        which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
      </src-license>
    </src-title>
  </active*>

  <use-package|generic|compact-list|presentation|ridged-paper>

  \;
</body>

<\initial>
  <\collection>
    <associate|sfactor|7>
  </collection>
</initial>